Upload
======

.. warning::

   The upload module will be removed from thumbor's codebase soon and ported to an extension.

.. toctree::
   :maxdepth: 2

   how_to_upload_images
   posting_putting_deleting
   create_my_own_storage
